import unittest
import numpy as np
import xarray as xr
from tinysunset.tools.bootrstrap import _xbootstrap, _find_crossover_quantile

class TestBootstrapFunctions(unittest.TestCase):

    def setUp(self):
        self.da1 = xr.DataArray(np.random.rand(10), dims="time")
        self.da2 = xr.DataArray(np.random.rand(10), dims="time")
        self.func = lambda x, y: x + y

    def test_xbootstrap(self):
        result = _xbootstrap(self.func, "time", 100, self.da1, self.da2)
        self.assertEqual(result.dims, ("n_sim", "time"))
        self.assertEqual(result.shape, (100, 10))

    def test_xbootstrap_with_none(self):
        result = _xbootstrap(self.func, "time", 100, self.da1, None, self.da2)
        self.assertEqual(result.dims, ("n_sim", "time"))
        self.assertEqual(result.shape, (100, 10))

    def test_find_crossover_quantile(self):
        dist1 = np.random.rand(100)
        dist2 = np.random.rand(100)
        quantile = _find_crossover_quantile(dist1, dist2)
        self.assertTrue(0 <= quantile <= 1)

if __name__ == "__main__":
    unittest.main()