
"Tests for tinysunset.scalers module."

import pytest
import numpy as np
import xarray as xr


def test_standard_scaler():
    """Test StandardScaler."""

    from tinysunset.scalers import StandardScaler, ScalerConfig

    _da = xr.DataArray(
        np.random.randn(50, 25),
        dims=["time", "ensemble"],
        coords={
            "time": np.arange(1950, 2000),
            "ensemble": np.arange(25),
        }
    )
        
    _scaler = StandardScaler(
        ScalerConfig(
        clim_type="clim",
        clim_ref_years=[1950, 2000],
        std_ref_years=[1950, 2000],
        time_dim="time",
        ensemble_dim="ensemble"
        )
    )
    
    _scaler.fit(_da)
    
    assert _scaler.mean == 0
    assert _scaler.std == 1
    
    
def test_robust_scaler():
    """Test RobustScaler."""

    from tinysunset.scalers import RobustScaler, ScalerConfig

    _da = xr.DataArray(
        np.random.randn(50, 25),
        dims=["time", "ensemble"],
        coords={
            "time": np.arange(1950, 2000),
            "ensemble": np.arange(25),
        }
    )
        
    _scaler = RobustScaler(
        ScalerConfig(
        clim_type="clim",
        clim_ref_years=[1950, 2000],
        std_ref_years=[1950, 2000],
        time_dim="time",
        ensemble_dim="ensemble"
        )
    )
    
    _scaler.fit(_da)
    
    assert _scaler.median == 0
    assert _scaler.iqr == 1 
    

